@@ -20,64 +20,61 @@
 #' ex1 <- ex1_db2so
 #' result <- classic.to.sym(ex1, concept=c('state', 'sex'),
 #'                          variables=c('county', 'group', 'age','age'),
-#'                          variables.types=c('$C', '$I', '$M', '$S'))
+#'                          variables.types=c('$C', '$I', '$H', '$S'))
 #' result
 #' @keywords symbolic data table
 #' @export
 #' @import sqldf
 #'
 classic.to.sym <- function(dataTable, concept, variables, variables.types) {
-
+    
     if (length(variables) != length(variables.types)) {
         stop("variables and variables.types must have the same length")
     }
-
-    dataTable <- dataTable[, which(colnames(dataTable) %in% c(variables,
-        concept))]
-
+    
+    dataTable <- dataTable[, which(colnames(dataTable) %in% c(variables, concept))]
+    
     concept <- paste0("[", concept, "]")
     variables <- paste0("[", variables, "]")
     conceptColumns <- paste(concept, collapse = ", ")
-
+    
     sqldf()
-
-    sqldf(paste0("CREATE INDEX main.concept_index ON dataTable (",
-        conceptColumns, ")"))
-
-    sym.obj <- sqldf(paste0("SELECT DISTINCT ", conceptColumns, " FROM main.dataTable ORDER BY ",
+    
+    sqldf(paste0("CREATE INDEX main.concept_index ON dataTable (", conceptColumns, 
+        ")"))
+    
+    sym.obj <- sqldf(paste0("SELECT DISTINCT ", conceptColumns, " FROM main.dataTable ORDER BY ", 
         conceptColumns))
     sym.obj.names <- do.call("paste", args = c(sym.obj, sep = "."))
-
+    
     symObjTable <- data.frame(SymObjNames = sym.obj.names)
-
+    
     sqldf("SELECT SymObjNames FROM symObjTable")
-
+    
     meta.data <- list()
     for (i in 1:length(variables)) {
-
+        n <- as.numeric(stringr::str_extract(variables.types[[i]], "[[:digit:]]"))
+        variables.types[[i]] <- stringr::str_replace(variables.types[[i]], "[[:digit:]]", 
+            "")
         switch(variables.types[[i]], `$C` = {
-            meta.data[[i]] <- process.continuum.variable(variables[[i]],
-                conceptColumns)
+            meta.data[[i]] <- process.continuum.variable(variables[[i]], conceptColumns)
         }, `$I` = {
-            meta.data[[i]] <- process.interval.variable(variables[[i]],
-                conceptColumns)
+            meta.data[[i]] <- process.interval.variable(variables[[i]], conceptColumns)
         }, `$H` = {
-            meta.data[[i]] <- process.histogram.variable(variables[[i]],
-                concept, dataTable)  #se agrega el parametro dataTable
+            meta.data[[i]] <- process.histogram.variable(variables[[i]], concept, dataTable, 
+                n)
         }, `$M` = {
-            meta.data[[i]] <- process.modal.variable(variables[[i]],
-                concept, sym.obj.names)
+            meta.data[[i]] <- process.modal.variable(variables[[i]], concept, sym.obj.names)
         }, `$S` = {
-            meta.data[[i]] <- process.set.variable(variables[[i]],
-                concept, sym.obj.names)
+            meta.data[[i]] <- process.set.variable(variables[[i]], concept, sym.obj.names)
         }, stop("Invalid variable type"))
     }
-
+    
     sqldf()
-
+    
     meta.data <- data.frame(meta.data, check.names = F)
     rownames(meta.data) <- sym.obj.names
-
+    
     colnames(meta.data)[colnames(meta.data) == "'$C'"] <- "$C"
     colnames(meta.data)[colnames(meta.data) == "'$I'"] <- "$I"
     new.sym <- newSobject(meta.data)
@@ -94,53 +91,51 @@ classic.to.sym <- function(dataTable, concept, variables, variables.types) {
         if (any(j > length(out$sym.var.names))) {
             stop("undefined columns selected")
         }
-
+        
         meta.data <- data.frame(row.names = out$sym.obj.names, check.names = F)
         real.data <- data.frame(row.names = out$sym.obj.names, check.names = F)
         new.var.l <- c()
         new.var.s <- c()
-
+        
         if (any(j < 0)) {
             j <- seq_along(out$sym.var.names)[j]
         }
-
+        
         for (columns in j) {
-
+            
             for (column in columns) {
                 type <- out$sym.var.types[column]
                 var.l <- out$sym.var.length[column]
                 var.s <- out$sym.var.starts[column]
-
+                
                 if (type %in% c("$H", "$M", "$S")) {
                   new.var.s <- c(new.var.s, ncol(meta.data) + 3)
-
-                  data. <- out$meta[, (var.s - 2):(var.s + (var.l -
-                    1))]
+                  
+                  data. <- out$meta[, (var.s - 2):(var.s + (var.l - 1))]
                   meta.data <- cbind(meta.data, data.)
-
+                  
                   data. <- out$meta[, (var.s):(var.s + (var.l - 1))]
                   real.data <- cbind(real.data, data.)
-
+                  
                   new.var.l <- c(new.var.l, ncol(data.))
                 }
                 if (type %in% c("$I")) {
                   new.var.s <- c(new.var.s, ncol(meta.data) + 2)
                   new.var.l <- c(new.var.l, 2)
-
-                  data. <- out$meta[, (var.s - 1):(var.s + (var.l -
-                    1))]
+                  
+                  data. <- out$meta[, (var.s - 1):(var.s + (var.l - 1))]
                   meta.data <- cbind(meta.data, data.)
-
+                  
                   data. <- out$meta[, (var.s):(var.s + 1)]
                   real.data <- cbind(real.data, data.)
-
+                  
                 }
                 if (type %in% c("$C")) {
                   new.var.s <- c(new.var.s, ncol(meta.data) + 2)
                   new.var.l <- c(new.var.l, 1)
                   data. <- out$meta[, (var.s - 1):(var.s)]
                   meta.data <- cbind(meta.data, data.)
-
+                  
                   data. <- out$meta[var.s]
                   real.data <- cbind(real.data, data.)
                 }
@@ -176,11 +171,27 @@ classic.to.sym <- function(dataTable, concept, variables, variables.types) {
 #'
 #' @export
 print.sym.data.table <- function(x, ...) {
-    cat("# A Symbolic Data Table : ", nrow(x$meta), " x ", length(x$sym.var.starts),
+    cat("# A Symbolic Data Table : ", nrow(x$meta), " x ", length(x$sym.var.starts), 
         "\n")
     print(format_sym_vars(x), ...)
 }
 
+#' Pander method for symbolic data table
+#'
+#' Prints a symbolic data table in Pandoc's markdown
+#' @param x a symbolic data table
+#' @param caption caption (string) to be shown under the table
+#' @param ... optional parameters passed to raw pandoc.table function
+#' @export
+pander.sym.data.table <- function(x, caption = attr(x, "caption"), ...) {
+    if (is.null(caption)) {
+        caption <- paste0("A Symbolic Data Table : ", nrow(x$meta), " x ", length(x$sym.var.starts), 
+            "\n")
+    }
+    pander::pander(format_sym_vars(x), caption, ...)
+}
+
+
 
 #' format.sym.vars
 #' @keywords internal
@@ -188,10 +199,9 @@ format_sym_vars <- function(x) {
     out.table <- c()
     for (i in seq_len(x$M)) {
         var.type <- x$sym.var.types[i]
-        var <- switch(var.type, `$C` = format_continuous_var(x, i),
-            `$M` = format_modal_var(x, i), `$H` = format_hist_var(x,
-                i), `$S` = format_set_var(x, i), `$I` = format_interval_var(x,
-                i))
+        var <- switch(var.type, `$C` = format_continuous_var(x, i), `$M` = format_modal_var(x, 
+            i), `$H` = format_hist_var(x, i), `$S` = format_set_var(x, i), `$I` = format_interval_var(x, 
+            i))
         out.table <- cbind(out.table, var)
     }
     out.table <- data.frame(out.table)
@@ -206,7 +216,7 @@ format_hist_var <- function(x, i) {
     var <- x[, i]$meta
     var <- var[, -c(1, 2)]
     out <- apply(var, 1, function(x) {
-        paste0(names(x), ":", (round(x, 2)*100), "%", collapse = " ")
+        paste0(names(x), ":", (round(x, 2) * 100), "%", collapse = " ")
     })
     return(out)
 }
@@ -218,7 +228,7 @@ format_set_var <- function(x, i) {
     var <- var[, -c(1, 2)]
     k <- colnames(var)
     out <- apply(var, 1, function(x) {
-
+        
         paste0("{", paste0(k[as.logical(x)], collapse = ","), "}")
     })
     return(out)
@@ -231,7 +241,7 @@ format_modal_var <- function(x, i) {
     var <- x[, i]$meta
     var <- var[, -c(1, 2)]
     out <- apply(var, 1, function(x) {
-        paste0(stringr::str_trunc(names(x), 3), ":",(round(x, 2)*100), "% ", collapse = "")
+        paste0(stringr::str_trunc(names(x), 3), ":", (round(x, 2) * 100), "% ", collapse = "")
     })
     return(out)
 }
@@ -251,6 +261,6 @@ format_continuous_var <- function(x, i) {
 format_interval_var <- function(x, i) {
     var <- x[, i]$meta
     var <- var[, -1]
-    out <- paste0("[", round(var[, 1],2), ",", round(var[, 2],2), "]")
+    out <- paste0("[", round(var[, 1], 2), ",", round(var[, 2], 2), "]")
     return(out)
 }
